@@ -15,8 +15,8 @@ NumericVector update(NumericVector x, double epsilon, double rho, double phi)
 
   for (int i = 0; i < (2 * n); ++i)
   {
-    j = ceil(i / 2);
-    epsilon_temp = pow(-1, i) * epsilon;
+    j = ceil(float(i / 2));
+    epsilon_temp = (1 - 2 * (i % 2)) * epsilon;
     current_value = x[j];
     updated_value = current_value + epsilon_temp;
 
@@ -34,7 +34,6 @@ NumericVector update(NumericVector x, double epsilon, double rho, double phi)
         epsilon_temp = epsilon_temp / pow(rho, f);
         updated_value = current_value + epsilon_temp;
     }
-
     if (updated_value > 1 || updated_value < 0)
       updated_value = current_value;
     x_updated[i] = updated_value;
